User Guide
==========

This section provides comprehensive guidance for using the ExactCIs package.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quick_reference
   examples/basic_usage
   examples/method_selection
   examples/rare_events
   troubleshooting